@java.lang.SuppressWarnings("serial")
class UtilityClassInner {
	static final class UtilClass implements java.io.Serializable {
		@java.lang.SuppressWarnings("all")
		@lombok.Generated
		private UtilClass() {
			throw new java.lang.UnsupportedOperationException("This is a utility class and cannot be instantiated");
		}
	}
}
